@@ -12,7 +12,7 @@ from aaindex import aaindex1
 amino_acids = ["A", "C", "D", "E", "F", "G", "H", "I", "K", "L", "M", "N", "P", 
     "Q", "R", "S", "T", "V", "W", "Y"]
 
-def aa_composition(sequence):
+def amino_acid_composition(sequence):
     """
     Calculate Amino Acid Composition (AAComp) of protein sequence. AAComp
     describes the fraction of each amino acid type within a protein sequence,
@@ -250,7 +250,7 @@ def pseudo_amino_acid_composition(sequence, lamda=30, weight=0.05, properties=["
         )
 
     #get amino acid composition
-    aa_comp = aa_composition(sequence)    
+    aa_comp = amino_acid_composition(sequence)    
     result = {}
     #applying weighting factor to components
     temp = 1 + weight * right_part
@@ -453,7 +453,7 @@ def amphiphilic_pseudo_aac(sequence, lamda=30, weight=0.5, properties=["ARGP8201
         right_part = right_part + sum(
             amphiphilic_sequence_order_correlation_factor(sequence, k=i + 1)
         )
-    aa_comp = aa_composition(sequence)
+    aa_comp = amino_acid_composition(sequence)
 
     amp_pseudo_amino_acid_composition = {}
     temp = 1 + weight * right_part
